@@ -115,7 +115,7 @@ learner_train = function(learner, task, train_row_ids = NULL, test_row_ids = NUL
   err = learner_will_err(cond, learner, stage = "train")
 
   # we don't log an existing (uncaught) error, because it's signalled
-  log = append_log(NULL, "train", result$log$class, result$log$msg, log_error = !err)
+  log = append_log(NULL, "train", result$log$class, result$log$msg, result$log$condition, log_error = !err)
 
   if (err) {
     stop(cond)
@@ -224,7 +224,7 @@ learner_predict = function(learner, task, row_ids = NULL) {
   if (task$nrow == 0L) {
     # return an empty prediction object, #421
     lg$debug("No observations in task, returning empty prediction data", task = task)
-    learner$state$log = append_log(learner$state$log, "predict", "output", "No data to predict on, create empty prediction")
+    learner$state$log = append_log(learner$state$log, "predict", "output", condition = "No data to predict on, create empty prediction")
     return(create_empty_prediction_data(task, learner))
   }
 
@@ -263,7 +263,7 @@ learner_predict = function(learner, task, row_ids = NULL) {
 
     pdata = result$result
     # don't log an existing (uncaught) error, because it's signalled
-    learner$state$log = append_log(learner$state$log, "predict", result$log$class, result$log$msg, log_error = !err)
+    learner$state$log = append_log(learner$state$log, "predict", result$log$class, result$log$msg, result$log$condition, log_error = !err)
 
     if (err) {
       stop(cond)
@@ -289,7 +289,7 @@ learner_predict = function(learner, task, row_ids = NULL) {
       lg$debug("Creating new Prediction using fallback '%s'",
         fb$id, learner = fb$clone())
 
-      learner$state$log = append_log(learner$state$log, "predict", "output", "Using fallback learner for predictions")
+      learner$state$log = append_log(learner$state$log, "predict", "output", condition = "Using fallback learner for predictions")
       pdata = predict_fb(task$row_ids)
     } else {
       miss_ids = is_missing_prediction_data(pdata)
@@ -298,7 +298,7 @@ learner_predict = function(learner, task, row_ids = NULL) {
         length(miss_ids), length(pdata$row_ids), fb$id, learner = fb$clone())
 
       if (length(miss_ids)) {
-        learner$state$log = append_log(learner$state$log, "predict", "output", "Using fallback learner to impute predictions")
+        learner$state$log = append_log(learner$state$log, "predict", "output", condition = "Using fallback learner to impute predictions")
 
         pdata = c(pdata, predict_fb(miss_ids), keep_duplicates = FALSE)
       }
@@ -520,21 +520,29 @@ process_model_after_predict = function(learner, store_models, is_sequential, unm
   }
 }
 
-append_log = function(log = NULL, stage = NA_character_, class = NA_character_, msg = character(), log_error = TRUE) {
+append_log = function(log = NULL, stage = NA_character_, class = NA_character_, msg = character(), condition = NULL, log_error = TRUE) {
   if (is.null(log)) {
     log = data.table(
       stage = factor(levels = c("train", "predict")),
       class = factor(levels = c("output", "warning", "error"), ordered = TRUE),
-      msg = character()
+      msg = character(),
+      condition = list()
     )
   }
 
+  # extract messages from conditions
+  if (length(condition)) {
+    msg = map_chr(condition, function(x) if (inherits(x, "condition")) conditionMessage(x) else x)
+  }
+
   if (length(msg)) {
+    log = rbindlist(list(log, data.table(stage = stage, class = class, msg = msg, condition = condition)), use.names = TRUE)
+
+    # log messages with lgr / print to console
     pwalk(list(stage, class, msg), function(s, c, m) {
       if (c == "error" && log_error) lg$error("%s: %s", s, m)
       if (c == "warning") lg$warn("%s: %s", s, m)
     })
-    log = rbindlist(list(log, data.table(stage = stage, class = class, msg = msg)), use.names = TRUE)
   }
 
   log
